<ul>
{% for entry in object_list %}
    <li>
    <h2><a href="{{ entry.get_absolute_url }}">{{ entry.title }}</a></h2>
    <p>Published on {{ entry.published_on }} by {{ entry.author }}</p>
    <p>{{ entry.content|striptags|truncatewords:20 }}</p>
    </li>
{% endfor %}
</ul>


{% if is_paginated %}
<p>Page {{ page_obj.number }} of {{ paginator.num_pages }}.
  {% if page_obj.has_previous%}
    <a href="?page={{ page_obj.previous_page_number }}">Previous Page</a>.
  {% endif %}
  {% if page_obj.has_next %}
    <a href="?page={{ page_obj.next_page_number }}">Next Page</a>.
  {% endif %}
</p>
{% endif %}
