<h2>Published on {{ day|date:"F jS, Y" }}</h2>

<ul>
{% for entry in object_list %}
    <li>
        <a href="{{ entry.get_absolute_url }}">{{ entry.title }}</a>
    </li>
{% endfor %}
</ul>

<h2>Stats for {{ day|date:"F jS, Y" }}</h2>
<p>Total Words written: {{ total_words }}</p>
<table>
  <caption>Most Common words</caption>
  <thead>
    <tr><th>Word</th><th>Times Used</th></tr>
  </thead>
  <tbody>
    {% for word, count in most_common %}
      <tr><td>{{ word }}</td><td>{{ count }}</td></tr>
    {% endfor %}
  </tbody>
</table>

{% if previous_day or next_day %}
    <p>
    {% if previous_day %}
        {% with y=previous_day|date:"Y" m=previous_day|date:"m" d=previous_day|date:"d"%}
         <a href="{% url 'blargg:entry_archive_day' y m d %}">{{ previous_day|date:"F jS, Y" }}</a>.
        {% endwith %}
    {% endif %}

    {{ day|date:"F jS, Y" }}.

    {% if next_day %}
        {% with y=next_day|date:"Y" m=next_day|date:"m" d=next_day|date:"d"%}
        <a href="{% url 'blargg:entry_archive_day' y m d %}">{{ next_day|date:"F jS, Y" }}</a>.
        {% endwith %}
    {% endif %}
    </p>
{% endif %}
