# Generated by Django 2.1.4 on 2018-12-28 18:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('blargg', '0002_auto_20181228_1711'),
    ]

    operations = [
        migrations.AlterField(
            model_name='entry',
            name='content_format',
            field=models.CharField(choices=[('md', 'Markdown'), ('rst', 'reStructured Text'), ('html', 'HTML')], max_length=4),
        ),
    ]
